@@ -1,9 +1,10 @@
 from .hier_plot import plot_hclust, plot_hclust_props
-from .tally import hcluster_tally, neighborhood_tally
+from .tally import hcluster_tally, neighborhood_tally, running_neighborhood_tally
 from .association_testing import cluster_association_test
 
 __all__ = ['hcluster_tally',
-		   'neighborhood_tally', 
+		   'neighborhood_tally',
+		   'running_neighborhood_tally', 
            'cluster_association_test',
            'plot_hclust',
            'plot_hclust_props']
