@@ -9,7 +9,6 @@ from scipy.spatial import distance
 import scipy.cluster.hierarchy as sch
 
 import json
-from escapejson import escapejson
 
 """jinja2 import triggers DeprecationWarning about imp module"""
 from jinja2 import Environment, PackageLoader#, FileSystemLoader
@@ -145,7 +144,7 @@ def _hclust_paths(Z, height, width, margin=10, res=None, alpha_col='pvalue', alp
             
             if not prune_col is None:
                 """Prune (don't print) if all member results are also prune=True"""
-                prune = res.loc[res['cid'].isin(cid_res['members']), prune_col].all()
+                prune = res.loc[res['cid'].isin(cid_res['children']), prune_col].all()
                 if prune:
                     continue
             paths.append(dict(coords=[[xscale(x), yscale(y)] for x,y in zip(xx, yy)], stroke='black', stroke_width=1))
@@ -202,4 +201,4 @@ def _translate_paths(paths):
             else:
                 tmp += 'L%f,%f' % tuple(c)
         paths[j]['str_coords'] = tmp
-    return paths
\ No newline at end of file
+    return paths
